pub trait LLStore: LLReader + LLWriter { }Expand description
Combined read/write at the LL level.
This is a convenience trait for stores that support both reading and writing.
It is automatically implemented for any type that implements both LLReader
and LLWriter.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".